﻿using Vezbe5i6.Models;

namespace Vezbe5i6.Repository
{
    public class ProductInMemoryRepository : IProductRepository
    {
        //lista proizvoda
        private readonly List<Product> _data = new();

        public ProductInMemoryRepository()
        {
            //test podaci koji ce se uvek ucitati
            _data.Add(new Product { ProductId = 1, Name = "Sony televzor 50''", Code = "01", Active = true, Category = new Category { CategoryId = 1 }, Description = "LED TV", Price = 850, ImageName = "sony_50_nd.jpg" });
            _data.Add(new Product { ProductId = 2, Name = "Samsung tv 40''", Code = "02", Active = true, Category = new Category { CategoryId = 1 }, Description = "LED TV", Price = 540, ImageName = "samsung_40_nd.jpg" });
            _data.Add(new Product { ProductId = 3, Name = "Ves masina LG", Code = "03", Active = true, Category = new Category { CategoryId = 2 }, Description = "Ves masina akcija", Price = 620, ImageName = "vesmasina_lg_nd.jpg" });
            _data.Add(new Product { ProductId = 4, Name = "Dell monitor 24''", Code = "04", Active = true, Category = new Category { CategoryId = 3 }, Description = "LED TV", Price = 240, ImageName = "dell_montor_24_nd.jpg" });
        }

        public IEnumerable<Product> GetAll()
        {
            return _data;
        }
        public IEnumerable<Product> GetWithFilter(string filter, int[] categories)
        {
            //filter text prebaci sve u mala slova
            filter = filter.ToLower();
            //iz liste proizvoda vrati samo proizvode kojima se u sifri ili nazivu nalazi sdrzaj iz filtera
            return _data.Where(p => p.Name.ToLower().Contains(filter) || p.Code.ToLower().Contains(filter))
                //dodaj filtriranje proizvoda koji se nalaze u filteru kategorija
                .Where(p => !categories.Any() || (p.Category != null && categories.Contains(p.Category.CategoryId)));
        }
        public Product? GetSingle(int productId)
        {
            return _data.FirstOrDefault(p => p.ProductId == productId);
        }
        public void Delete(int productId)
        {
            //brisanje proizvoda iz liste po productid
            _data.RemoveAll(p => p.ProductId == productId);
        }
        public int Save(Product product)
        {
            //provera da li proizvoda sa tom sifrom vec postoji ako postoji vrati -10
            if (_data.Any(p => p.Code == product.Code && p.ProductId != product.ProductId))
            {
                return -10;
            }
            //ako je productid 0 radi insert
            if (product.ProductId == 0)
            {
                //simulacija auto increment productid
                var maxID = _data.Max(p => p.ProductId);
                product.ProductId = maxID + 1;
                //dodavanje proizvoda u listu
                _data.Add(product);
            }
            else
            {
                //izmena proizvoda kroz prikaz brisanja i dodavanja u listu

                //izvuci podatak iz liste
                var c = _data.FirstOrDefault(p => p.ProductId == product.ProductId);
                //obrisi proizvod iz liste
                _data.Remove(c);
                //dodaj izmenjen proizvod
                _data.Add(product);
            }
            return product.ProductId;
        }
    }
}
